%%%%%%%%%%%%%%%%
%%%
%%
%%  Obzory matematiky, fyziky a informatiky
%%
%%  LaTeX2e Class
%%%%%%%%%%%%%%%%


%%%%%%%%%    NEW

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{obzory_en}[2017]

\DeclareOption{twoside}  {\relax}
\DeclareOption{titlepage}{\relax}
\DeclareOption{twocolumn}{\relax}
\DeclareOption{pteqn}{\AtEndOfClass{
      \@addtoreset{equation}{section}
      \def\theequation{\thesection.\arabic{equation}}
}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\DeclareOption{a4paper}
   {\setlength\paperheight {297mm}%
    \setlength\paperwidth  {210mm}}
\ExecuteOptions{a4paper}
\ProcessOptions
\LoadClass[twoside,onecolumn,notitlepage,11pt,a4paper,leqno]{article}
\RequirePackage{latexsym}
\RequirePackage{amsthm}
\RequirePackage[cp1250]{inputenc}
\RequirePackage[IL2]{fontenc}
\RequirePackage[labelsep=period,center]{caption}
\RequirePackage{microtype}

\RequirePackage{enumitem}
\setlist{nolistsep,leftmargin=1.5em}
\renewcommand{\labelenumii}{\alph{enumii})}
\renewcommand{\labelitemi}{\boldmath$\cdot$}
\renewcommand{\labelitemii}{}

\renewcommand{\rmdefault}{ptm}

\setlength {\textwidth}      {130mm}
\setlength {\textheight}     {184mm}
\setlength {\oddsidemargin}  {14.6mm}
\setlength {\evensidemargin} {14.6mm}
\setlength {\topmargin}      {14mm}
\setlength {\headheight}     {7mm}
\setlength {\headsep}        {8mm}
\setlength {\footnotesep}    {10pt}
\setlength {\parindent}      {1.5em}

\addtolength{\voffset}{-20pt}
\def\footnoterule{\medskip\hrule width .2\columnwidth height .8\p@\bigskip}

\setlength{\abovecaptionskip}{5pt}

\renewcommand{\captionfont}{\it\small}
\renewcommand{\captionlabelfont}{\it\small}
\renewcommand{\thefigure}{\arabic{figure}}
\renewcommand{\thetable}{\arabic{table}}

\def\obrazokname{Figure}
\def\fnum@figure{\obrazokname\nobreakspace\thefigure}

\def\tabulkaname{Table}
\def\fnum@table{\tabulkaname\nobreakspace\thetable}

\let\oldfigure\figure
\def\figure{\@ifnextchar[\figure@i \figure@ii}
\def\figure@i[#1]{\oldfigure[#1]\centering}
\def\figure@ii{\oldfigure\centering}

\let\oldtable\table
\def\table{\@ifnextchar[\table@i \table@ii}
\def\table@i[#1]{\oldtable[#1]\centering\footnotesize}
\def\table@ii{\oldtable\centering\footnotesize}


\renewcommand{\thebibliography}[1] {\section*{\hspace{-5mm}
{\normalsize\raggedright\mdseries \textls*[250]{References}}}%
      \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{\small #1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}

\renewcommand{\@openbib@code}{%
  \parskip=2pt
  \topsep=0pt
  \itemsep=0pt
  \parsep=0pt
  \small}


% DEFINITION OF PAGESTYLE
\def\ps@ObzoryHlavicka{%
    \let\@oddfoot\@empty\let\@evenfoot\@empty
    \def\@evenhead{\it{\small\thepage}\hfil\leftmark\hfil}%
    \def\@oddhead{\it\hfil\rightmark\hfil{\small\thepage}}%
    \let\@mkboth\@gobbletwo
    \let\sectionmark\@gobble
    \let\subsectionmark\@gobble
    }

\AtBeginDocument{%
  \@ifundefined{volinfo}{%
    \def\volinfo{%
      Volume \currentvolume, Number \number0\currentissue
      \if\@printyear , \currentmonth\ \currentyear\fi
    }%
  }{}%
}

\def\issueinfo#1#2#3{\def\currentvolume{#1}\def\currentissue{#2}%
\def\currentyear{#3}}
\issueinfo{00}% volume number
  {0}%        % issue number
  {XXXX}%     % year


\AtBeginDocument{%
        \pagestyle{ObzoryHlavicka}
        \markboth{}{}
}%

\renewcommand{\maketitle}{\par
  \begingroup
    \global\@topnum\z@   % Prevents figures from going at top of page.
    {\raggedright\scriptsize OBZORY MATEMATIKY, FYZIKY A~INFORMATIKY
    \currentissue/\currentyear\ (\currentvolume)\vskip 1em}
    \null%
    \begin{minipage}{0.85\textwidth}
      {\fontsize{17}{\f@baselineskip}\bfseries\@title}\\[1.5em]%
      {\fontsize{13}{15}\bf
       \lineskip .5em%
       \@author
       \par}\vskip 1.5em%
    \end{minipage}\\[1.5em]
    %
    {\fontsize{11}{\f@baselineskip}\it \@Dedication\vskip 1.2em}
    {\small
    \@Abstract\vskip 0.5em
    \@KeyWords\vskip 0.5em
    \@Suhrn\vskip 0.5em
    \@KlucoveSlova\vskip 0.5em
    \@MESC\vskip 2em}%
  \endgroup
  \let\true@oddhead\@oddhead


  \setcounter{footnote}{0}%
  \global\let\maketitle\relax
  \global\let\@author\@empty
  \global\let\@dedicated\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\dedicated\relax
  \global\let\and\relax
}

\newcommand{\@Abstract}{\relax}
\newcommand{\Abstract}[1]{%
  \renewcommand{\@Abstract}{%
   \centerline{ \begin{minipage}{0.85\textwidth}
\textbf{Abstract:} {#1}
\end{minipage}}
   }
}

\newcommand{\@KeyWords}{\relax}
\newcommand{\KeyWords}[1]{%
  \renewcommand{\@KeyWords}{%
   \centerline{ \begin{minipage}{0.85\textwidth}
\textbf{Key words:} {#1}
\end{minipage}}
   }
}

\newcommand{\@Suhrn}{\relax}
\newcommand{\Suhrn}[2]{%
  \renewcommand{\@Suhrn}{%
   \centerline{ \begin{minipage}{0.85\textwidth}
\textbf{Shrn [#1]:} {#2}
\end{minipage}}
   }
}

\newcommand{\@KlucoveSlova}{\relax}
\newcommand{\KlucoveSlova}[1]{%
  \renewcommand{\@KlucoveSlova}{%
   \centerline{ \begin{minipage}{0.85\textwidth}
\textbf{Kov slov:} {#1}
\end{minipage}}
   }
}

\newcommand{\@MESC}{\relax}
\newcommand{\MESC}[1]{%
  \renewcommand{\@MESC}{%
   \centerline{ \begin{minipage}{0.85\textwidth}
\textbf{MESC:} {#1}
\end{minipage}}
   }
}

\newcommand{\@Dedication}{\relax}
\newcommand{\Dedication}[1]{%
  \renewcommand{\@Dedication}{%
  \centerline{ \begin{minipage}{0.85\textwidth} {#1}
\end{minipage}}
   }
}

\global\let\thanks\relax
\global\let\@thanks\@empty

\newcommand{\@dedicated}{\relax}
\newcommand{\dedicated}[1]
   {\renewcommand{\@dedicated}{#1\vskip 1.3em\relax}}


\setcounter{secnumdepth}{1}

\renewcommand\section{\@startsection{section}{1}{5mm}%
                            {-3.5ex \@plus -1ex \@minus -.2ex}%
                            {2.3ex \@plus.2ex}%
                            {\normalfont\large\bfseries\flushleft}}

\renewcommand\subsection{\@startsection{subsection}{2}{0mm}%
                            {-0.5ex\@plus -5ex \@minus -.2ex}%
                            {1.0ex \@plus .2ex}%
                            {\normalfont\normalsize\itshape\flushleft}}

\renewcommand\subsubsection{\@startsection{subsubsection}{3}{0mm}%
                            {-0.5ex\@plus -5ex \@minus -.2ex}%
                            {1.0ex \@plus .2ex}%
                            {\normalfont\normalsize\itshape\flushleft}}

\def\qedname{$\Box$}

\newtheoremstyle{obzory_theorem}% name
{}%      Space above, empty = `usual value'
{}%      Space below
{\itshape}% Body font
{}%         Indent amount (empty = no indent, \parindent = para indent)
{\bfseries}% Thm head font
{\\}%
{ }%
{}%
%%

\newtheoremstyle{obzory_definition}% name
{}%      Space above, empty = `usual value'
{}%      Space below
{}% Body font
{}%         Indent amount (empty = no indent, \parindent = para indent)
{\bfseries}% Thm head font
{\\}%
{ }%
{}%
%%

\newtheoremstyle{obzory_remark}% name
{}%      Space above, empty = `usual value'
{}%      Space below
{}% Body font
{}%         Indent amount (empty = no indent, \parindent = para indent)
{}% Thm head font
{\ }%
{ }%
{{{\itshape\thmname{#1}\thmnumber{ #2}.}{\upshape\thmnote{ [#3]}}}}%
%%

\theoremstyle{obzory_theorem}
\newtheorem{theorem}{Theorem}[section]
\newtheorem*{theorem*}{Theorem}
\newtheorem{lemma}[theorem]{Lemma}%[section]
\newtheorem*{lemma*}{Lemma}%
\newtheorem{problem}[theorem]{Problem}%[section]
\newtheorem*{problem*}{Problem}%
\newtheorem{corollary}[theorem]{Corollary}%[section]
\newtheorem*{corollary*}{Corollary}%

\theoremstyle{obzory_definition}
\newtheorem{definition}[theorem]{Definition}%[section]
\newtheorem*{definition*}{Definition}%
\newtheorem{example}[theorem]{Example}%[section]
\newtheorem*{example*}{Example}
\newtheorem{exercise}[theorem]{Exercise}%[section]
\newtheorem*{exercise*}{Exercise}

\theoremstyle{obzory_remark}
\newtheorem{remark}[theorem]{Remark}%[section]
\newtheorem*{remark*}{Remark}
\newtheorem{solution}[theorem]{Solution}%[section]
\newtheorem*{solution*}{Solution}%
\newtheorem*{interpretation}{Interpretation}%

\renewcommand\proofname{Proof}

\newcommand{\@Acknowledgement}{\relax}
\newcommand{\Acknowledgement}[1]{
    \renewcommand{\@Acknowledgement}
    {{\noindent \bf Acknowledgement:\hspace{1ex}}#1\vskip 1.3em\relax}}

\newcommand\Authors[1]{
\vspace{3ex}
\@Acknowledgement
{\fontsize{9}{11}\selectfont\raggedright
\noindent Authors' addresses:\\[5pt]
#1}}

\newcommand\Author[1]{
\vspace{3ex}
\@Acknowledgement
{\footnotesize{
\noindent Author's address:\\[5pt]
#1}}}

\newcommand\email[1]{e-mail: {\tt #1}\\[5pt]}

\newcounter{graph}
\def\thegraph{\arabic{graph}}
\newcommand{\legend}[1]{{\small\it Graph\hspace{1ex}\thegraph.\ \,#1}}
\newenvironment{graph}{
\refstepcounter{graph}
\begin{center}}{\end{center}}

\endinput
